# Solaris
$self->{CCFLAGS} = $Config{ccflags} . ' -D__EXTENSIONS__ -DHAS_X_UT_EXIT -DHAS_X_UT_HOST -DHAS_X_UT_SYSLEN -DLEN_X_UT_USER=32 -DLEN_X_UT_ID=4 -DLEN_X_UT_LINE=32 -DLEN_X_UT_HOST=257 -DHAS_UTMPXNAME';
